@@ -45,7 +45,15 @@ def click_element(selector):
     selector = re.sub(r"(:)", r"\\\1", selector) # двоеточие -> \:
     selector = re.sub(r"(\[)", r"\\\1", selector) # [ -> \[
     selector = re.sub(r"(\])", r"\\\1", selector) # ] -> \]
+    paste(f"copy(document.querySelector('{selector}'))")
+    temp_bufer = False
+    while  temp_bufer is False:
+        time.sleep(1)
+        paste(f"copy(document.querySelector('{selector}'))")
+        temp_bufer = get_bufer()
+
     paste(f"document.querySelector('{selector}').click()")
+    print('Успешный клик')
     time.sleep(0.5)
 
 
